@@ -25,7 +25,7 @@
 class AkPlugin
 {
     public:
-        virtual ~AkPlugin() {}
+        virtual ~AkPlugin();
 
         virtual QObject *create(const QString &name, const QString &spec) = 0;
         virtual QStringList keys() const = 0;
