@@ -50,7 +50,7 @@ QObject *DizzyElement::controlInterface(QQmlEngine *engine, const QString &contr
 
     // Create a context for the plugin.
     QQmlContext *context = new QQmlContext(engine->rootContext());
-    context->setContextProperty("Dizzy", (QObject *) this);
+    context->setContextProperty("Dizzy", const_cast<QObject *>(qobject_cast<const QObject *>(this)));
     context->setContextProperty("controlId", this->objectName());
 
     // Create an item with the plugin context.
@@ -84,7 +84,7 @@ qreal DizzyElement::strength() const
 
 void DizzyElement::setSpeed(qreal speed)
 {
-    if (this->m_speed == speed)
+    if (qFuzzyCompare(this->m_speed, speed))
         return;
 
     this->m_speed = speed;
@@ -93,7 +93,7 @@ void DizzyElement::setSpeed(qreal speed)
 
 void DizzyElement::setZoomRate(qreal zoomRate)
 {
-    if (this->m_zoomRate == zoomRate)
+    if (qFuzzyCompare(this->m_zoomRate, zoomRate))
         return;
 
     this->m_zoomRate = zoomRate;
@@ -102,7 +102,7 @@ void DizzyElement::setZoomRate(qreal zoomRate)
 
 void DizzyElement::setStrength(qreal strength)
 {
-    if (this->m_strength == strength)
+    if (qFuzzyCompare(this->m_strength, strength))
         return;
 
     this->m_strength = strength;
