@@ -28,6 +28,22 @@
 //#define CODEC_COMPLIANCE FF_COMPLIANCE_EXPERIMENTAL
 #define THREAD_WAIT_LIMIT 500
 
+struct XRGB
+{
+    quint8 x;
+    quint8 r;
+    quint8 g;
+    quint8 b;
+};
+
+struct BGRX
+{
+    quint8 b;
+    quint8 g;
+    quint8 r;
+    quint8 x;
+};
+
 typedef QMap<AVMediaType, QString> AvMediaTypeStrMap;
 
 inline AvMediaTypeStrMap initAvMediaTypeStrMap()
@@ -501,7 +517,7 @@ QVariantMap MediaSink::defaultCodecParams(const QString &codec)
                                                 QString(av_get_sample_fmt_name(codecContext->sample_fmt)):
                                                 supportedSampleFormats.value(0, "s16");
         codecParams["defaultBitRate"] = codecContext->bit_rate?
-                                            (qint64) codecContext->bit_rate: 128000;
+                                            qint64(codecContext->bit_rate): 128000;
         codecParams["defaultSampleRate"] = codecContext->sample_rate?
                                                codecContext->sample_rate:
                                                supportedSampleRates.value(0, 44100);
@@ -559,7 +575,7 @@ QVariantMap MediaSink::defaultCodecParams(const QString &codec)
         codecParams["defaultGOP"] = codecContext->gop_size > 0?
                                         codecContext->gop_size: 12;
         codecParams["defaultBitRate"] = codecContext->bit_rate?
-                                            (qint64) codecContext->bit_rate: 200000;
+                                            qint64(codecContext->bit_rate): 200000;
         codecParams["defaultPixelFormat"] = codecContext->pix_fmt != AV_PIX_FMT_NONE?
                                             QString(av_get_pix_fmt_name(codecContext->pix_fmt)):
                                             supportedPixelFormats.value(0, "yuv420p");
@@ -708,7 +724,7 @@ QVariantMap MediaSink::addStream(int streamIndex,
                 if (diff < maxDiff) {
                     frameRate = rate.value<AkFrac>();
 
-                    if (!diff)
+                    if (qIsNull(diff))
                         break;
 
                     maxDiff = diff;
@@ -737,8 +753,8 @@ QVariantMap MediaSink::addStream(int streamIndex,
             videoCaps.setProperty("bitrate", QVariant());
             break;
         case AV_CODEC_ID_ROQ:
-            videoCaps.width() = qPow(2, qRound(qLn(videoCaps.width()) / qLn(2)));
-            videoCaps.height() = qPow(2, qRound(qLn(videoCaps.height()) / qLn(2)));
+            videoCaps.width() = int(qPow(2, qRound(qLn(videoCaps.width()) / qLn(2))));
+            videoCaps.height() = int(qPow(2, qRound(qLn(videoCaps.height()) / qLn(2))));
             videoCaps.fps() = AkFrac(qRound(videoCaps.fps().value()), 1);
             break;
         case AV_CODEC_ID_RV10:
@@ -887,7 +903,7 @@ QVariantMap MediaSink::updateStream(int index, const QVariantMap &codecParams)
                     if (diff < maxDiff) {
                         frameRate = rate.value<AkFrac>();
 
-                        if (!diff)
+                        if (qIsNull(diff))
                             break;
 
                         maxDiff = diff;
@@ -916,8 +932,8 @@ QVariantMap MediaSink::updateStream(int index, const QVariantMap &codecParams)
                 videoCaps.setProperty("bitrate", QVariant());
                 break;
             case AV_CODEC_ID_ROQ:
-                videoCaps.width() = qPow(2, qRound(qLn(videoCaps.width()) / qLn(2)));
-                videoCaps.height() = qPow(2, qRound(qLn(videoCaps.height()) / qLn(2)));
+                videoCaps.width() = int(qPow(2, qRound(qLn(videoCaps.width()) / qLn(2))));
+                videoCaps.height() = int(qPow(2, qRound(qLn(videoCaps.height()) / qLn(2))));
                 videoCaps.fps() = AkFrac(qRound(videoCaps.fps().value()), 1);
                 break;
             case AV_CODEC_ID_RV10:
@@ -986,7 +1002,7 @@ void MediaSink::flushStreams()
             if (stream->codec->frame_size <= 1)
                 continue;
 
-            qint64 pts = this->m_streamParams[i].audioPts();
+            qint64 pts = this->m_streamParams[int(i)].audioPts();
             int ptsDiff = stream->codec->codec->capabilities
                           & AV_CODEC_CAP_VARIABLE_FRAME_SIZE?
                               1:
@@ -1012,7 +1028,7 @@ void MediaSink::flushStreams()
                 pkt.pts = pkt.dts = pts;
                 pts += ptsDiff;
                 av_packet_rescale_ts(&pkt, stream->codec->time_base, stream->time_base);
-                pkt.stream_index = i;
+                pkt.stream_index = int(i);
                 av_interleaved_write_frame(this->m_formatContext, &pkt);
                 av_packet_unref(&pkt);
             }
@@ -1038,9 +1054,9 @@ void MediaSink::flushStreams()
                 if (!gotPacket)
                     break;
 
-                pkt.pts = pkt.dts = this->m_streamParams[i].nextPts(0, 0);
+                pkt.pts = pkt.dts = this->m_streamParams[int(i)].nextPts(0, 0);
                 av_packet_rescale_ts(&pkt, stream->codec->time_base, stream->time_base);
-                pkt.stream_index = i;
+                pkt.stream_index = int(i);
                 av_interleaved_write_frame(this->m_formatContext, &pkt);
                 av_packet_unref(&pkt);
             }
@@ -1048,6 +1064,25 @@ void MediaSink::flushStreams()
     }
 }
 
+QImage MediaSink::swapChannels(const QImage &image) const
+{
+    QImage swapped(image.size(), image.format());
+
+    for (int y = 0; y < image.height(); y++) {
+        const XRGB *src = reinterpret_cast<const XRGB *>(image.constScanLine(y));
+        BGRX *dst = reinterpret_cast<BGRX *>(swapped.scanLine(y));
+
+        for (int x = 0; x < image.width(); x++) {
+            dst[x].x = src[x].x;
+            dst[x].r = src[x].r;
+            dst[x].g = src[x].g;
+            dst[x].b = src[x].b;
+        }
+    }
+
+    return swapped;
+}
+
 AkVideoCaps MediaSink::nearestDVCaps(const AkVideoCaps &caps) const
 {
     AkVideoCaps nearestCaps;
@@ -1062,7 +1097,7 @@ AkVideoCaps MediaSink::nearestDVCaps(const AkVideoCaps &caps) const
         if (k < q) {
             nearestCaps = sCaps;
             q = k;
-        } else if (k == q && sCaps.format() == caps.format())
+        } else if (qFuzzyCompare(k, q) && sCaps.format() == caps.format())
             nearestCaps = sCaps;
     }
 
@@ -1086,7 +1121,7 @@ AkVideoCaps MediaSink::nearestDNxHDCaps(const AkVideoCaps &caps) const
             nearestCaps = sCaps;
             nearestCaps.fps() = fps;
             q = k;
-        } else if (k == q && sCaps.format() == caps.format())
+        } else if (qFuzzyCompare(k, q) && sCaps.format() == caps.format())
             nearestCaps = sCaps;
     }
 
@@ -1468,8 +1503,8 @@ bool MediaSink::init()
 
             AkFrac timeBase(configs["timeBase"].value<AkFrac>());
 
-            stream->time_base.num = timeBase.num();
-            stream->time_base.den = timeBase.den();
+            stream->time_base.num = int(timeBase.num());
+            stream->time_base.den = int(timeBase.den());
         } else if (streamCaps.mimeType() == "video/x-raw") {
             AkVideoCaps videoCaps(streamCaps);
 
@@ -1490,8 +1525,8 @@ bool MediaSink::init()
                 videoCaps.setProperty("bitrate", QVariant());
                 break;
             case AV_CODEC_ID_ROQ:
-                videoCaps.width() = qPow(2, qRound(qLn(videoCaps.width()) / qLn(2)));
-                videoCaps.height() = qPow(2, qRound(qLn(videoCaps.height()) / qLn(2)));
+                videoCaps.width() = int(qPow(2, qRound(qLn(videoCaps.width()) / qLn(2))));
+                videoCaps.height() = int(qPow(2, qRound(qLn(videoCaps.height()) / qLn(2))));
                 videoCaps.fps() = AkFrac(qRound(videoCaps.fps().value()), 1);
                 break;
             case AV_CODEC_ID_RV10:
@@ -1518,8 +1553,8 @@ bool MediaSink::init()
             stream->codec->height = videoCaps.height();
 
             AkFrac timeBase(configs["timeBase"].value<AkFrac>());
-            stream->time_base.num = timeBase.num();
-            stream->time_base.den = timeBase.den();
+            stream->time_base.num = int(timeBase.num());
+            stream->time_base.den = int(timeBase.den());
             stream->codec->time_base = stream->time_base;
 
             stream->codec->gop_size = configs["gop"].toInt();
@@ -1813,8 +1848,11 @@ void MediaSink::writeVideoPacket(const AkVideoPacket &packet)
     oFrame.width = codecContext->width;
     oFrame.height = codecContext->height;
 
-    AkVideoPacket videoPacket = AkUtils::roundSizeTo(packet.toPacket(), 4);
-    videoPacket = AkUtils::convertVideo(videoPacket, AkVideoCaps::Format_rgb24);
+    AkPacket videoPacket = packet.toPacket();
+    QImage image = AkUtils::packetToImage(videoPacket);
+    image = image.convertToFormat(QImage::Format_RGB32);
+    image = this->swapChannels(image);
+    videoPacket = AkUtils::imageToPacket(image, videoPacket);
 
     if (!this->m_streamParams[streamIndex].convert(videoPacket, &oFrame)) {
         av_frame_unref(&oFrame);
