@@ -29,6 +29,7 @@ inline StringStringMap initGstToFF()
     gstToFF["I420"] = "yuv420p";
 //    gstToFF["YV12"] = "";
     gstToFF["YUY2"] = "yuyv422";
+    gstToFF["YUYV"] = "yuyv422";
     gstToFF["UYVY"] = "uyvy422";
 //    gstToFF["AYUV"] = "";
     gstToFF["RGBx"] = "rgb0";
@@ -106,13 +107,13 @@ AkPacket ConvertVideo::convert(const AkPacket &packet, const AkCaps &oCaps)
     AkVideoCaps oVideoCaps(oCaps);
 
     GstBuffer *iBuffer = gst_buffer_new_allocate(NULL,
-                                                 videoPacket.buffer().size(),
+                                                 gsize(videoPacket.buffer().size()),
                                                  NULL);
     GstMapInfo info;
     gst_buffer_map(iBuffer, &info, GST_MAP_WRITE);
     memcpy(info.data,
            videoPacket.buffer().constData(),
-           videoPacket.buffer().size());
+           size_t(videoPacket.buffer().size()));
     gst_buffer_unmap(iBuffer, &info);
 
     QString iFormat = AkVideoCaps::pixelFormatToString(videoPacket.caps().format());
@@ -122,8 +123,8 @@ AkPacket ConvertVideo::convert(const AkPacket &packet, const AkCaps &oCaps)
                                          "width", G_TYPE_INT, videoPacket.caps().width(),
                                          "height", G_TYPE_INT, videoPacket.caps().height(),
                                          "framerate", GST_TYPE_FRACTION,
-                                                      (int) videoPacket.caps().fps().num(),
-                                                      (int) videoPacket.caps().fps().den(),
+                                                      int(videoPacket.caps().fps().num()),
+                                                      int(videoPacket.caps().fps().den()),
                                          NULL);
 
     GstSample *iSample = gst_sample_new(iBuffer,
@@ -153,24 +154,30 @@ AkPacket ConvertVideo::convert(const AkPacket &packet, const AkCaps &oCaps)
         qDebug() << "Error:" << error->message;
         g_error_free(error);
 
-        if (oSample != NULL)
+        if (oSample)
             gst_sample_unref(oSample);
 
+        if (iBuffer)
+            gst_buffer_unref(iBuffer);
+
         return AkPacket();
     }
 
     GstBuffer *bufffer = gst_sample_get_buffer(oSample);
     gst_buffer_map(bufffer, &info, GST_MAP_READ);
-    QByteArray oBuffer(info.size, Qt::Uninitialized);
+    QByteArray oBuffer(int(info.size), Qt::Uninitialized);
     memcpy(oBuffer.data(), info.data, info.size);
     gst_buffer_unmap(bufffer, &info);
 
-    if (iSample != NULL)
+    if (iSample)
         gst_sample_unref(iSample);
 
-    if (oSample != NULL)
+    if (oSample)
         gst_sample_unref(oSample);
 
+    if (iBuffer)
+        gst_buffer_unref(iBuffer);
+
     // Create packet
     AkVideoPacket oPacket(packet);
     oPacket.caps() = oVideoCaps;
